Move-class:
The Move class
Description
The Move object contains at least time and coordinate information of an animal. It can contain further data that are individual to the animal, e.g. the sex or age. These data are stored in the idData data.frame. If the object was created with the Movebank browsing functions it does also contain the study name, licence and citation information.
Slots
- idData
- Object of class
"data.frame": additional (one row) data; - dateCreation
- Object of class
"numeric": time stamp when the file was downloaded; - study
- Object of class
"character": name of the study; - citation
- Object of class
"character": how to cite the study; - license
- Object of class
"character": the license under which the data were published; - timesMissedFixes
- Object of class
"POSIXct": stores the timestamps of lines of the data set that were removed because they included NA locations - bbox
- belongs to the SpatialPointsDataFrame
- coords
- coordinates of the track, belongs to the SpatialPointsDataFrame
- coords.nrs
- belongs to the SpatialPointsDataFrame
- data
- additional data of that object that is stored in the SpatialPointsDataFrame
- proj4string
- projection of the coordinates
- timestamps
- timestamps according to the coordinates
Methods
movesignature(object = "Move"): creates a Move object getMovebankDatasignature(object = "character"): creates a Move object by accessing Movebank spTransformsignature(object = "Move"): transforms coordinates to a different projection method showsignature(object = "Move"): prints a summary of all data stored in the Move object as.data.framesignature(object = "Move"): extracts the spatial data frame coordinatessignature(object = "Move"): extracts the coordinates only from the Move object proj4stringsignature(object = "Move"): extracts the projection method from the Move object time.lagsignature(object = "Move"): calculates time lags between coordinates n.locssignature(object = "Move"): calculates number of locations plotsignature(object = "Move"): plots the track of the animal