MoveBurst: MoveBurst class
Description
The class MoveBurst, used for storing information about one individual with assignments of segments. Every segment between to locations has a class for example behavioural category. Slots
- bbox
- ...
- burstId
- ...
- citation
- ...
- coords
- ...
- coords.nrs
- ...
- data
- ...
- dateCreation
- ...
- idData
- ...
- license
- ...
- proj4string
- ...
- sensor
- ...
- study
- ...
- timesMissedFixes
- ...
- timestamps
- ...