Learn R Programming

move (version 2.0.0)

MoveStack-class: The MoveStack class

Description

The MoveStack object is created within the brownian.bridge.dyn function from a Move object. It includes among others a raster object and probabilities.

Arguments

Slots

citation
Object of class "dBMvariance": includes the break.list and points of interest, ...;
bbox
belongs to the SpatialPointsDataFrame
coords
the extension factor set by the user
coords.nrs
belongs to the SpatialPointsDataFrame
data
additional data of that object that is stored in the SpatialPointsDataFrame
dateCreation
date and timestamp when this object was created
idData
additional data to all individuals
license
the license terms of the used track material
proj4string
projection of all coordinates
study
name of the study
timestamps
timestamps according to the coordinates
trackId
a vector that indicates, which data, coordinates and timestamps belong to an individual

Methods

Methods defined with class "MoveStack" in the signature:
[
signature(x="MoveStack"): select subset ...
getMovebankData
signature(object = "character"): creates a MoveStack object by accessing Movebank