Learn R Programming

move (version 2.0.0)

UDStack: Creating UDStack objects

Description

The function enables the easy generation of .UDStacks, which is forexample useful for using other UD function such as getVolumeUD.

Usage

UDStack(x,...)

Arguments

x
A list or raster brick/stack that needs to be converted to a .UDStack object
...
Currently not used

Value

Examples

Run this code
data(dbbmmstack)
stk<-as(dbbmmstack,"RasterStack")
UDStack(stk)
lst<-split(dbbmmstack)
UDStack(lst)

Run the code above in your browser using DataLab