Learn R Programming

move (version 2.0.0)

angle: angle information from a track or track stack

Description

This function returns a summary about angle related measurements of a track or track stack. These are: average azimuth, variance of azimuth, standard error of azimuth.

Usage

"angle"(x) "angle"(x) "angleSummary"(x) "angleSummary"(x)

Arguments

x
Move or MoveStack object

Value

Angles in degrees

Examples

Run this code
## Not run:   
# data(leroy)
# data(fishers)
#   angle(leroy) #angles from a Move object 
#   angle(fishers) #angles from a MoveStack object
# #  angleSummary(leroy) # summary of angle measures of a Move object
# #  angleSummary(fishers) # summary of angle measures of a MoveStack object
# ## End(Not run)# failed on cran build

Run the code above in your browser using DataLab