Learn R Programming

move (version 2.0.0)

brownian.motion.variance.dyn: Calculates the dynamic brownian motion variance

Description

A function to calculate the dynamic brownian motion variance for a movement track. It can be used by advanced programmers to program against.

Usage

"brownian.motion.variance.dyn"(object, location.error, window.size, margin)

Arguments

object
An object of the Move-class, that can be used for variance calculation. It needs to be in a flat coordinate system.
location.error
A numeric vector with the location error.
window.size
The window size used for the variance calculation.
margin
The margin size used for variance calculation.

Value

An object of the type dBMvariance is returned

References

Kranstauber, B., Kays, R., LaPoint, S. D., Wikelski, M. and Safi, K. (2012), A dynamic Brownian bridge movement model to estimate utilization distributions for heterogeneous animal movement. Journal of Animal Ecology. doi: 10.1111/j.1365-2656.2012.01955.x

See Also

brownian.bridge.dyn

Examples

Run this code
data(leroy)
data2 <- spTransform(leroy[1:80,], CRSobj="+proj=aeqd +ellps=WGS84", center=TRUE)
err<-rep(23.5,n.locs(data2))
dBMvar <- brownian.motion.variance.dyn(data2, location.error=err, margin=13, window.siz=31)
dBMvar

Run the code above in your browser using DataLab