Learn R Programming

move (version 2.0.0)

citations: Extract the citation of a Move or MoveStack object

Description

The citations method returns or sets the citation of a track from a Move or MovesStack object.

Usage

"citations"(obj) "citations"(obj) <- value

Arguments

obj
Move or MoveStack object
value
citation from class character

Examples

Run this code
  data(leroy)
  citations(leroy) #get the citation from a Move object
  citations(leroy) <- "No paper available" #change the citation and set it for a Move object
  data(fishers)
  citations(fishers) #get the citation from a MoveStack object
  citations(fishers) <- "Nothing to cite" #change the citation and set it for a MoveStack object

Run the code above in your browser using DataLab