Learn R Programming

move (version 2.0.0)

coordinates: Extract the track coordinates from a Move/MoveStack object

Description

The coordinates method extracts the coordinates of a track.

Usage

"coordinates"(obj,...)

Arguments

obj
A valid Move or MoveStack object
...
Additional arguments, see Details

Details

Returns a matrix with the coordinates of the track in a Move or MoveStack object.

Examples

Run this code
## create a move object
data(leroy)
## extract the coordinates
coords <- coordinates(leroy)

Run the code above in your browser using DataLab