Learn R Programming

move (version 2.0.0)

dBMvarianceTmp: dBMvarianceTmp class

Description

The class dBMvarianceTmp is mostly an internal class that is made public to make inheritance easier. It is a basal class that stores results of the dbbmm

Arguments

Slots

window.size
The window size used for dbbmm calculation
margin
The margin used for dbbmm calculation
means
...
in.windows
...
interest
...
break.list
...