Learn R Programming

move (version 1.1.424)

distance: distance information from a track or track stack

Description

DistanceSummary returns a summary of distance related measurements of a track or track stack, or for the distance function the distance between locations.

Usage

## S3 method for class '.MoveTrackSingle':
distance(x)
  ## S3 method for class '.MoveTrackStack':
distance(x)
  ## S3 method for class '.MoveTrackSingle':
distanceSummary(x)
  ## S3 method for class '.MoveTrackStack':
distanceSummary(x)

Arguments

x
Move or MoveStack object

Value

  • All values are returned in meters if the projection of the coordinates is longlat, otherwise their in map units mostly meters as well. For longlat distance on a sphere is calculated else on a plane. Check and set the projection of your Move or MoveStack object using the proj4string() function.

Examples

Run this code
load(system.file("extdata", "move.RData", package="move"), .GlobalEnv)
  stack <- moveStack(list(leroy,leroy))
  
  distance(leroy) #distances from a Move object 
  distance(stack) #distances from a MoveStack object
  distanceSummary(leroy) # summary of distance measures of a Move object
  distanceSummary(stack) # summary of distance measures of a MoveStack object

Run the code above in your browser using DataLab