Rdocumentation
powered by
Learn R Programming
move (version 2.0.0)
dynBGBvariance: calculate variance for a track using a running window
Description
the function uses
windowApply
with the
BGBvarbreak
function in order to implement a dynaminc calculation of the variance
Arguments