Learn R Programming

move (version 2.0.0)

getMotionVariance: Returns the estimated motion variance

Description

This function returns from an object where it has been calculated before

Usage

getMotionVariance(x,...)

Arguments

x
A variance object or an UD object calculated using the dynamic Bivariate Gaussian Bridges or dynamic Brownian Bridges
...
Currently un used

See Also

brownian.bridge.dyn, dynBGB

Examples

Run this code
data(leroydbbmm)
data(dbbmmstack)
getMotionVariance(leroydbbmm)
  getMotionVariance(dbbmmstack)

Run the code above in your browser using DataLab