Learn R Programming

move (version 2.0.0)

getMovebankData: Download data from Movebank

Description

getMovebankData downloads the location and timestamp columns of a study stored in Movebank

Usage

getMovebankData(study, animalName, login, ...)

Arguments

study
character, full name of the study, as stored on Movebank
animalName
character, single or a vector, with the name of the individuals as stored on Movebank
login
a MovebankLogin, if empty you'll be asked to enter your username or password
...
passing on additional arguments

Details

getMovebankData belongs to the Movebank browsing functions and returns a Move object from studies with only on animal or MoveStack object for studies with multiple animals. If only a single or several particular animals of a study should be downloaded, a character vector can be provided for the animalName argument. Remember that you need an account at Movebank.org, see movebankLogin.

See Also

movebankLogin

Examples

Run this code
## Not run: 
# #obtain a login
# login<-movebankLogin()
# getMovebankData(study="BCI Ocelot", login=login) 
# #returns a MoveStack object from the specified study
# getMovebankData(study="BCI Agouti", login=login) 
# #returns a Move object (there is only one individual in this study)
# getMovebankData(study=123413, animalName=c("Mancha","Yara"), login=login) 
# #returns a MoveStack with two individuals
# ## End(Not run)

Run the code above in your browser using DataLab