Learn R Programming

move (version 1.1.424)

getVolumeUD: Modify a UD raster

Description

Modifies the UD raster: that the cell values of the resulting raster are equal to the percentage of the smallest home range containing this cell.

Usage

## S3 method for class '.UD':
getVolumeUD(x, ...)

Arguments

x
one or several objects of the DBBMM-class or an DBBMMStack-class object
...
additional Raster or DBBMM objects

Examples

Run this code
load(system.file("extdata", "move.RData", package="move"), .GlobalEnv)

getVolumeUD(leroydbbmm) #for a single object
getVolumeUD(dbbmmstack)
getVolumeUD(leroydbbmm, leroydbbmm, leroydbbmm) #for several objects 

plot(getVolumeUD(leroydbbmm))

Run the code above in your browser using DataLab