Learn R Programming

move (version 2.0.0)

interpolateTime: Interpolate a trajectory

Description

This function allows to interpolate trajectories. It does this on the basis of a simple interpolation, depending on the spaceMethod that is specified.

Usage

interpolateTime(x, time, spaceMethod=c('euclidean','greatcircle','rhumbline'),...)

Arguments

x
an object of the Move-class
time
either timestamps, or a number of locations or time interval that is used to generate a sequence of timestamps using the seq function
spaceMethod
a character that indicates the interpolation function to be used
...
other arguments currently not used

Examples

Run this code
  data(leroy)
  plot(interpolateTime(leroy[1:200,], 700,'gr'))

Run the code above in your browser using DataLab