Learn R Programming

move (version 2.0.0)

lines: Plotting a track as lines

Description

Function for plotting a recorded track from a Move object as lines

Usage

"lines"(x,...) "lines"(x,col=NA,...) "lines"(x,col=NA,...)

Arguments

x
Move object
col
a vector of colors (same length as the number of individual for a stack or number of burst levels or segments for a burst object, or one)
...
arguments to be passed on, e.g. lty or lwd.

See Also

points plot

Examples

Run this code
data(leroy)
data(leroydbbmm)
plot(leroydbbmm)
lines(spTransform(leroy, center=TRUE), col=3) # add a track from a Move object to a plot

Run the code above in your browser using DataLab