brownian.bridge.dyn |
| To calculate the utilization density |
coordinates |
| Track-coordinates of the Move Object |
as.data.frame |
| A data.frame with the important data of the Move Object |
n.locs |
| The number of locations |
timeLag |
| The time lags between the locations |
projection |
| The projection method of the track/raster |
plot |
| plots the utilization distribution with fixed width and height ratio (see DBBMM-class) |
| or the track (see Move-class) |
image |
| plots the utilization distribution fitted to the window |
contour |
| adds the contours of utilization distribution to a plot |