Learn R Programming

move (version 2.0.0)

n.indiv: Extract the number of individuals of a Move or MoveStack object

Description

The n.indiv function returns the number of individuals from a Move or MovesStack object.

Usage

"n.indiv"(obj) "n.indiv"(obj)

Arguments

obj
Move or MoveStack object

Details

The function returns 1 for objects of the class Move, and number of individuals for a moveStack

Examples

Run this code
data(leroy)
n.indiv(leroy)
data(fishers)
n.indiv(fishers)

Run the code above in your browser using DataLab