Learn R Programming

move (version 2.0.0)

points: Plotting the points of a track

Description

Function for plotting a recorded track from a Move object as points.

Usage

"points"(x,...) "points"(x,col=NA,...) "points"(x,...)

Arguments

x
Move or a DBBMM object
col
a vector of colors (same length as the number of objects)
...
arguments to be passed on, e.g. col for color, or add to add the points to a plot.

See Also

plot lines

Examples

Run this code
data(leroydbbmm)
data(leroy)
plot(leroydbbmm)
points(spTransform(leroy, center=TRUE), col=3) # add a track from a Move object to a plot

Run the code above in your browser using DataLab