The function converts a raster object to a SpatialLinesDataFrame.
Usage
## S3 method for class '.UD':
raster2contour(x, ...)
## S3 method for class '.UDStack':
raster2contour(x, ...)
Arguments
x
a DBBMM or DBBMMStack object, that includesa raster object
...
additional arguments that are passed on from other functions, most important being level which determines the contour level
Details
The raster2contour function creates a SpatialLinesDataFrame from a given raster or DBBMM object. This allows to re-project the contours to different projections.