Learn R Programming

move (version 2.0.0)

searchMovebankStudies: Search for a study

Description

Searches for a study within Movebank

Usage

searchMovebankStudies(x, login)

Arguments

x
a character string to search within the Movebank study names
login
an object of the MovebankLogin-class, if empty you'll be asked to enter your username or password

Value

Details

The search function searches explicitly for the entered phrase. If you for example type 'Goose' it will not show you studies including 'goose'. So rather search for 'oose' to find both.

Examples

Run this code
## Not run: 
# searchMovebankStudies("MPIO", login=login) #returns all studies that include this exact term
# ## End(Not run)

Run the code above in your browser using DataLab