Learn R Programming

move (version 2.0.0)

show: Show a Move object

Description

Displays a summary of a Move object.

Usage

"show"(object) "show"(object)

Arguments

object
a Move or MoveStack object

Details

The show function displays a summary of a Move object. This includes:
  • animal ID
  • species name
  • study name
  • number of track points
  • receiver type
  • projection method
  • date of file creation
  • the first three lines of the spatial data frame
  • study citation
  • data license
  • number of omitted locations due to NAs in the dataset

If the imported data are not from the Movebank database Animal, Species, nPoints, Receiver, and Study are not shown.