Learn R Programming

move (version 1.1.424)

speed: speed information from a track or track stack

Description

This function returns a summary of speed related measurements of a Move or MoveStack object.

Usage

## S3 method for class '.MoveTrackSingle':
speed(x)
  ## S3 method for class '.MoveTrackStack':
speed(x)
  ## S3 method for class '.MoveTrackSingle':
speedSummary(x)
  ## S3 method for class '.MoveTrackStack':
speedSummary(x)

Arguments

x
Move or MoveStack object

Value

  • The function returns the speed in m/s if the track is longlat else map units per second. In most cases the map units will also be meters.

Examples

Run this code
load(system.file("extdata", "move.RData", package="move"), .GlobalEnv)  
  stack <- moveStack(list(leroy,leroy))
  
  speed(ricky) #speeds from a Move object 
  speed(stack) #speeds from a MoveStack object
  speedSummary(leroy) # summary of speed measures of a Move object
  speedSummary(stack) # summary of speed measures of a MoveStack object

Run the code above in your browser using DataLab