A MoveStack is split into a list of Move objects by the track IDs of the given MoveStack.
For stacking moveStack can be used. Also a MoveBurst object can be split this will lead to seperate list elements for every burst, every location where the burst is switched will then be recycled.