Learn R Programming

move (version 2.0.0)

timeLag: Calculates the time lags between the coordinates

Description

The timeLag function calculates the time lags between locations.

Usage

"timeLag"(x,...) "timeLag"(x,units, ...)

Arguments

x
a Move or MoveStack object
units
The units used for the conversion, they need to be specified for a stack to ensure similair units between individuals
...
further arguments

Value

The function returns a numeric vector with the time lags.

Details

Optionally the argument units can be passed on to ensure the time lag in a certain unit, this is especially useful in case a move stack is bursted. For more information on the units argument see the help of difftime.

Examples

Run this code
data(fishers)
data(leroy)

head(timeLag(leroy,units="mins")) #calculate timelags for a Move object
head(timeLag(fishers,units="mins")) #calculate timelags for a MoveStack object
head(timeLag(fishers, units="hours")) #calculate timelags in different units

Run the code above in your browser using DataLab