Learn R Programming

move (version 2.0.0)

timestamps: Extract the timestamps of a Move or MoveStack object

Description

The timestamps method returns or sets the timestamps of a track from a Move or MovesStack object.

Usage

"timestamps"(this) "timestamps"(this) "timestamps"(this) <- value

Arguments

this
Move or MoveStack object
value
timestamps from class POSIXct

Examples

Run this code
data(leroy)
data(fishers)
  
  timestamps(leroy) #get the timestamps from a Move object
  timestamps(fishers) #get the timestamps from a MoveStack object
  #change the timestamps and set it for a Move object
  timestamps(leroy) <- timestamps(leroy)+60 
  #change the timestamps and set it for a MoveStack object
  timestamps(fishers) <- timestamps(fishers)+60 

Run the code above in your browser using DataLab