Learn R Programming

move (version 2.0.0)

trackId: Returns trackId

Description

Obtain a factor returning the ids of individuals per location

Usage

"trackId"(x)

Arguments

x
a MoveStack object

Value

Returns a factor indicating to which individuals locations belong in a stack.

Examples

Run this code
data(fishers)
  trackId(fishers)
  

Run the code above in your browser using DataLab