Learn R Programming

move (version 1.1.424)

unUsedRecords<-: Creates unused records data

Description

A function that assigns locations as unused or returns the unUsedRecords part of the object it could for example be used to remove locations test locations from a track.

Usage

## S3 method for class '.MoveTrackSingle,logical':
unUsedRecords(obj) <- value
  ## S3 method for class '.MoveTrackStack,logical':
unUsedRecords(obj) <- value
  ## S3 method for class '.unUsedRecords':
unUsedRecords(obj,...)
  ## S3 method for class '.unUsedRecordsStack':
unUsedRecords(obj,...)

Arguments

obj
a Move or MoveStack object
value
A logical vector of the same length as the number of locations
...
Not used at the moment

Examples

Run this code
data <- move(system.file("extdata","leroy.csv.gz",package="move"))
par(mfrow=2:1)
plot(data, type='b')
unUsedRecords(data)<-as.logical((1:n.locs(data))%%2)
plot(data, type='b')

Run the code above in your browser using DataLab