Learn R Programming

move (version 1.1.424)

split: Splitting a MoveStack

Description

Splitting MoveStack in a list of Move objects

Usage

## S3 method for class 'MoveStack,missing':
split(x, f, drop=FALSE, ...)

Arguments

x
MoveStack or MoveBurst object
f
not needed
drop
not needed
...
not needed

Details

A MoveStack is split into a list of Move objects by the track IDs of the given MoveStack. For stacking moveStack can be used. Also a MoveBurst object can be split this will lead to seperate list elements for every burst, every location where the burst is switched will then be recycled.

Examples

Run this code
load(system.file("extdata", "move.RData", package="move"), .GlobalEnv)
movestack <- moveStack(list(leroy,ricky))

split(movestack) #splitting a MoveStack
split(dbbmmstack) #splitting a DBBMMStack

Run the code above in your browser using DataLab