Rdocumentation
powered by
Learn R Programming
move (version 2.0.0)
time.lag: Calculates the time lags between the coordinates
Description
The time.lag function calculates the time lags between locations.
Usage
"time.lag"(x,...) "time.lag"(x,units, ...)
Arguments
x
a Move or MoveStack object
units
The units used for the conversion, they need to be specified for a stack to ensure similair units between individuals
...
further arguments
Details
This function is now replaced by timeLag