Learn R Programming

move (version 1.1.424)

turnAngleGc: Calculates turning angles on great circle tracks

Description

This function returns the turn angels of a great circle track.

Usage

## S3 method for class '.MoveTrackSingle':
turnAngleGc(x)

Arguments

x
Move object, in long lat projection

Value

  • The function returns the turning angles in degrees.

Details

On great circle tracks the bearing of arrival on a point is not the same as witch the previous point was left. This function returns the difference between these bearings between -180 and 180. The bearings are calculated using the functions bearing and finalBearing of the geosphere package.

Examples

Run this code
load(system.file("extdata", "move.RData", package="move"), .GlobalEnv)  
  turnAngleGc(leroy)

Run the code above in your browser using DataLab